from plotly.subplots import make_subplots
import plotly.graph_objects as go
import numpy as np

#define a numpy array with values 1 through 12
#for months of the year
month_numbers = np.arange(1,13,1)

#enter y values to be plotted in subplots
y_SOXL_20 = np.array([19.117, 18.381, 8.4513, 7.6654, 8.9377, 11.9071,
                      13.8474, 16.6998, 16.0077, 18.9785, 22.9896, 29.8183])
y_SOXL_21 = np.array([37.1862, 40.8165, 34.8042, 41.5752, 33.9699, 39.8208,
                      41.188, 44.2781, 45.8475, 41.9228, 62.2513, 65.5913])

#create a grid of subplots with subplot titles and shared y axes
fig = make_subplots(rows=1, cols=2,
                    subplot_titles=[
                        'Line chart for 2020',  # 1. subplot title
                        'Line chart for 2021'  # 2. subplot title
                                    ],
                    shared_yaxes=True
                    )

#configure subplot grid with traces
fig.add_trace(
    go.Scatter(x=month_numbers, y=y_SOXL_20,
               name = "SOXL_20",
               mode = "lines+markers"),
    row=1, col=1
)

fig.add_trace(
    go.Scatter(x=month_numbers, y=y_SOXL_21,
               name = "SOXL_21",
               mode = "lines+markers"),
    row=1, col=2
)

#update grid with parameter settings
#add figure title and assign height and width for fig image
fig.update_layout(
    height=600, width=800,
    title_text="Side-by-Side Subplots for Average Monthly Close Prices"
                )

# Update xaxes subplot titles
fig.update_xaxes(title_text="Month number in year", row=1, col=1)
fig.update_xaxes(title_text="Month number in year", row=1, col=2)

# Update yaxes subplot titles
fig.update_yaxes(title_text="Average Monthly Close Price", row=1, col=1)
fig.update_yaxes(title_text="Average Monthly Close Price", row=1, col=2)


#show figure with subplot grid for scatter line charts
fig.show()
